Users management — SoL 4 user manual

# Users management

To interact with the system, that is to be able to insert new tournaments and other entities, one must inserts his credentials into the login panel. Such credentials may be either granted by the administrator, or by a self registration.

A user may create new entities such as clubs, championships, players and tourneys, that are automatically assigned to him (in other words, he becomes the owner): while the administrator may modify everything in the system, all other users may change or delete only the entities belonging to them.

Contents

- Users management

  - Menu actions

  - Insert and edit

    - Email and password

    - First name and last name

    - Language

    - Owners admin

    - Players manager

    - Status

## Menu actions

In addition to the standard actions the menu at the top contains the following items:

Clubs

  Opens the management of the clubs which the selected user is responsible of

Championships

  Opens the management of the championships which the selected user is responsible of

Players

  Opens the management of the players which the selected user is responsible of

Ratings

  Opens the management of the ratings which the selected user is responsible of

Tourneys

  Opens the management of the tourneys which the selected user is responsible of

## Insert and edit

All fields, with the exception of language, are mandatory.

### Email and password

These are the credentials the user shall insert into the login panel. The email must be a valid address and the password may be anything longer than five characters.

Note

While the self registration procedure ascertains the validity of the email address, when it is inserted or modified manually no check is done that the address corresponds to an existing mailbox. It is therefore recommended to pay particular attention: a wrong value precludes the possibility of resetting the password should it be forgotten!

### First name and last name

These fields cannot be left empty.

### Language

If set, this overrides the browser's default when the user logs in.

### Owners admin

The administrator can grant a owners admin permission to particular users: when a user has this right he can change the ownership of other items (clubs, tournaments...), even of those not belonging to him.

### Players manager

The administrator can grant a players manager permission to particular users: when a user has this right he can insert new players, or modify and delete existing ones.

Note

Allow anyone to manage the list of players, as was the case with versions of SoL prior to 4, has caused numerous problems, primarily the presence of duplicates: a bit for laziness, a bit for linguistic difficulties, is clearly more hasty to reinsert a player who shows up at a tournament than to check if it is already present in the database.

Resolving these cases is not always easy when you do not know them in person.

With version 4 it was decided to be able to give the possibility to manage the players only to a clearly defined group of users: in principle there will be a set of recognized responsible, reasonably one for each country, leaving the insert and edit of individual players to those who know them and can to identify them.

### Status

The current status of the user:

Registered

  the self registration <signin> procedure has not been completed yet: users in this state cannot log in

Confirmed

  this is the normal state for an operational user